@@ -61,6 +61,7 @@ int main(int argc, char *argv[])
      options.gstrdup = 0;
 #endif
 
+     gtk_set_locale();
      gtk_init(&argc, &argv);
 
      /* Check args */
@@ -243,16 +244,13 @@ int init_keyboard_stuff(char *input)
 
      if(!file_exists(testbuffer))
      {
-	  fprintf(Q,"Using an RPM?  Changing documentation search path.\n");
-	  fprintf(Q,"If you're not using an RPM, and you get this message,\n");
-	  fprintf(Q,"it means GTKeyboard is confused as to where the docs ");
-	  fprintf(Q,"are.\n\n");
-          fprintf(Q,"You can explicitly tell GTKeyboard where they are by\n");
-          fprintf(Q,"using the extra_files variable in ~/.gtkeyboardrc.\n");
-          fprintf(Q,"See the MANUAL for more information.\n");
-	  fflush(Q);
-	  sprintf(options.extrafiles,"%susr%sshare%sgtkeyboard%s",
-		  _DIR, _DIR, _DIR, _DIR);
+          fprintf(Q,"Bad mojo: the path \"%s\" doesn't exist, which means\n",
+                  testbuffer);
+          fprintf(Q,"that you may have an incomplete or incorrect\n");
+          fprintf(Q,"installation of GTKeyboard.  If the application is\n");
+          fprintf(Q,"just confused about the location of the files, please\n");
+          fprintf(Q,"use the \"extra_files\" option in your .gtkeyboardrc.\n");
+          fprintf(Q,"For more help, see the documentation.\n");
      } /* End if */
      
      homeptr = getenv("HOME");
