@@ -355,7 +355,9 @@ void keysym_callback(GtkWidget *emitter, gpointer data)
      KeySym sym;
      char let;
      char buffer[1024];
-     char *keyname;
+     char *keyname = (char*)NULL;
+     char *altkeyname = (char*)NULL;
+     KeySym lower=(KeySym)NULL, upper=(KeySym)NULL;
 
 #ifdef PARANOID_DEBUGGING
      fprintf(Q,"keysym_callback():  Got (%s, %s, %s).\n",
@@ -365,11 +367,26 @@ void keysym_callback(GtkWidget *emitter, gpointer data)
 #endif /* PARANOID_DEBUGGING */
 
      /* Determine which of the syms in the KEY * structure to use. */
-     keyname = XKeysymToString(key->lower_case);
+     keyname    = XKeysymToString(key->lower_case);
+     altkeyname = XKeysymToString(key->alt_gr);
 
-     if(options.ALT_GR)
+     if(options.ALT_GR) 
+     {
 	  sym = key->alt_gr;
-     else if(strstr(keyname,"KP"))
+          /* We have only three symbols, and we have to generate
+           * the fourth one for cyrillic letters.
+           */
+          if(strstr(altkeyname, "Cyrillic_"))
+          {
+               XConvertCase(sym, &lower, &upper);
+
+               if(options.SHIFT || options.CAPS_LOCK)
+               { 
+                    sym = upper;
+               } /* End if */
+          } /* End if */
+     } /* End if */
+     else if(strstr(keyname, "KP"))
      {
 	  if(options.NUMLOCK)
 	       sym = key->upper_case;
@@ -432,6 +449,7 @@ void keysym_callback(GtkWidget *emitter, gpointer data)
      
      if(ELEMENTS.text)
           gtk_widget_show_all(GUI.main_output_text);
+
      return;
 } /* End keysym_callback() */
 
@@ -453,19 +471,22 @@ static GtkWidget *build_keyboard(GtkWidget *input, char *filename)
 {
      /* NEW BUILD_KEYBOARD() */
      GtkWidget *mainbox = gtk_vbox_new(FALSE, 0);
-     GtkWidget *hbox;
-     GtkWidget *button;
-     char *name;
-     GtkWidget *align;
+     GtkWidget *hbox    = (GtkWidget *)NULL;
+     GtkWidget *button  = (GtkWidget *)NULL;
+     char *name         = (char *)NULL;
+     char *altname      = (char *)NULL;
+     GtkWidget *align   = (GtkWidget *)NULL;
      char label[512];
      char tooltip_label[1024];
      char *errbuf = NULL;
      char *ptr;
      int rowno;
      int index;
-     char letter;
+     char letter = '\0';
+     char cyrletter = '\0';
      KEY *key;
      KeySym s;
+     KeySym altlower, altupper;
 
      /* Create the current keyboard in a new place. -- This takes care of
       * destroying our old ones for us.
@@ -514,11 +535,39 @@ static GtkWidget *build_keyboard(GtkWidget *input, char *filename)
 	       
 	       letter = (int)key->upper_case;
 	       name = XKeysymToString(key->upper_case);
+               altname = XKeysymToString(key->alt_gr);
 
 	       if(key->upper_case == XK_Mode_switch ||
 		  key->lower_case == XK_Mode_switch)
+               {
 		    sprintf(label," Alt Gr");
-	       else if(isalnum(letter) || ispunct(letter))
+               } /* End if */
+               else if(strstr(altname,"Cyrillic_")) 
+               {
+                    /* We have only lower case letter, let us
+                     * ask X to convert it to upper case.
+                     */
+                    XConvertCase(key->alt_gr, &altlower, &altupper);
+
+                    /* FIXME: Yes, this is totally wrong method to get
+                     * the cyrillic letter. It just happen to to
+                     * yield the right letter in koi8-r encoding.
+                     */   
+                    cyrletter = (char)altupper;
+                    if(!isalpha(letter))
+                    {
+                         sprintf(label," %c   \n %c  %c",
+                                 (char)key->upper_case,
+                                 (char)key->lower_case,
+                                 cyrletter);
+                    } /* End if */
+                    else
+                    {
+                         sprintf(label," %c   \n    %c",
+                                 (char)key->upper_case, cyrletter);
+                    } /* End else */
+               } /* End else if */
+	       else if((isalnum(letter) || ispunct(letter)) && (letter > 0))
 	       {
 		    if(!isalpha(letter))
 			 sprintf(label,"  %c  \n  %c",
