@@ -88,6 +88,20 @@ long sizeof_text_widget(GtkWidget *widget)
      return(rep);
 } /* End sizeof_text_widget */
 
+void toggle_tooltips(void)
+{
+     if(options.SHOW_TOOLTIPS) 
+     {
+          disable_tooltips();
+          options.SHOW_TOOLTIPS = 0;
+     }
+     else 
+     {
+          enable_tooltips();
+          options.SHOW_TOOLTIPS = 1;
+     } /* End else */
+} /* End toggle_tooltips() */
+
 void disable_tooltips(void)
 {
      if(GUI.tooltips)
@@ -106,7 +120,7 @@ void enable_tooltips(void)
      if(GUI.tooltips)
 	  gtk_tooltips_enable(GUI.tooltips);
      else gtkeyboard_message(1,"No tooltips defined.  This may be a bug.\n");
-
+     
      /* Toolbar tooltips are separate from the rest of the apps tooltips.
       * Damn.
       */
@@ -969,15 +983,17 @@ void load_layout_settings(GtkWidget *emitter, gpointer data)
       * save_layout_settings().
       */
      RCVARS ELEMENTS_rc_tokens[] = {
-          { NULL, "KBD_FONT",  RC_STR,  &GUI.kfontname,      NULL },
-          { NULL, "TXT_FONT",  RC_STR,  &GUI.fontname,       NULL },
-          { NULL, "COLOR",     RC_STR,  &GUI.colorname,      NULL },
-          { NULL, "TOOLBAR",   RC_BOOL, &ELEMENTS.toolbar,   NULL },
-          { NULL, "MENUBAR",   RC_BOOL, &ELEMENTS.menubar,   NULL },
-          { NULL, "KEYBOARD",  RC_BOOL, &ELEMENTS.keyboard,  NULL },
-          { NULL, "STATUS",    RC_BOOL, &ELEMENTS.status,    NULL },
-          { NULL, "TEXT",      RC_BOOL, &ELEMENTS.text,      NULL },
-          { NULL, "BUTTONBAR", RC_BOOL, &ELEMENTS.buttonbar, NULL },
+          { NULL, "KBD_FONT",  RC_STR,  &GUI.kfontname,         NULL },
+          { NULL, "TXT_FONT",  RC_STR,  &GUI.fontname,          NULL },
+          { NULL, "COLOR",     RC_STR,  &GUI.colorname,         NULL },
+          { NULL, "KBD_FILE",  RC_STR,  &options.keyboard_file, NULL },
+          { NULL, "TOOLTIPS",  RC_BOOL, &options.SHOW_TOOLTIPS, NULL },
+          { NULL, "TOOLBAR",   RC_BOOL, &ELEMENTS.toolbar,      NULL },
+          { NULL, "MENUBAR",   RC_BOOL, &ELEMENTS.menubar,      NULL },
+          { NULL, "KEYBOARD",  RC_BOOL, &ELEMENTS.keyboard,     NULL },
+          { NULL, "STATUS",    RC_BOOL, &ELEMENTS.status,       NULL },
+          { NULL, "TEXT",      RC_BOOL, &ELEMENTS.text,         NULL },
+          { NULL, "BUTTONBAR", RC_BOOL, &ELEMENTS.buttonbar,    NULL },
           { NULL, "KBD_KBD",   RC_BOOL, &GUI.keyboard_elements.show_keyboard, 
             NULL },
           { NULL, "KBD_NUMPAD",RC_BOOL, 
@@ -1031,6 +1047,8 @@ void save_layout_settings(GtkWidget *emitter, gpointer data)
           { NULL, "KBD_FONT",  RC_STR,  &GUI.kfontname,      NULL },
           { NULL, "TXT_FONT",  RC_STR,  &GUI.fontname,       NULL },
           { NULL, "COLOR",     RC_STR,  &GUI.colorname,      NULL },
+          { NULL, "KBD_FILE",  RC_STR,  &options.keyboard_file, NULL },
+          { NULL, "TOOLTIPS",  RC_BOOL, &options.SHOW_TOOLTIPS, NULL },
           { NULL, "TOOLBAR",   RC_BOOL, &ELEMENTS.toolbar,   NULL },
           { NULL, "MENUBAR",   RC_BOOL, &ELEMENTS.menubar,   NULL },
           { NULL, "KEYBOARD",  RC_BOOL, &ELEMENTS.keyboard,  NULL },
