@@ -56,9 +56,17 @@ static void cacheify_wrapper         (GtkWidget *emitter, gpointer data);
 static void cache_browser            (GtkWidget *emitter, gpointer data);
 static void cache_browser_insert_file(GtkWidget *emitter, gpointer data);
 
+/* Yeah, I'm lazy.  This WORD_FILE_ALTERNATIVES is the number of elements
+ * in word_file_alternatives
+ */
+#define WORD_FILE_ALTERNATIVES                            3
+char *word_file_alternatives[] = { "/usr/dict/words",
+                                   "/usr/share/dict/words",
+                                   "/usr/share/dict/american-english" };
+
 void destroy_completer_window(GtkWidget *emitter, gpointer data)
 {
-     register int x=0;
+     register int x = 0;
 
      if(completer_window && GTK_IS_WIDGET(completer_window))
           gtk_widget_destroy(completer_window);
@@ -70,9 +78,9 @@ void destroy_completer_window(GtkWidget *emitter, gpointer data)
           completion_slot[x] = NO_WIDGET;
      } /* End for */
 
-     inputlabel            = NO_WIDGET;
-     insert_trailing_space = NO_WIDGET;
-     show_unused_slots     = NO_WIDGET;
+     inputlabel              = NO_WIDGET;
+     insert_trailing_space   = NO_WIDGET;
+     show_unused_slots       = NO_WIDGET;
 
      if(completer)
      {
@@ -251,39 +259,26 @@ void cacheify_file_dialog(GtkWidget *emitter, gpointer data)
 static char *get_valid_cache_filename(void)
 {
      char *default_file = NULL;
+     int x = 0;
+     char *ptr = (char *)NULL;
      
-     if(!file_exists(DEFAULT_WORDLIST))
-     {
-          gtkeyboard_message(4, "The file ",DEFAULT_WORDLIST,
-                             " does not exist.\n",
-                             "Trying to use GTKeyboard word cache...\n");
+     for(x=0; x<WORD_FILE_ALTERNATIVES; x++) {
+          default_file = word_file_alternatives[x];
+
+#ifdef COMPLETER_DEBUGGING
+          gtkeyboard_message(3, "Attempting to open ", default_file, 
+                             " for reading as a wordlist...\n");
+#endif /* COMPLETER_DEBUGGING */
           
-          fprintf(Q,"Finding new file at %s%s%s\n",
-                  options.extrafiles, _DIR, DEFAULT_CACHE_FILENAME);
-          fflush(Q);
-
-          default_file = g_new0(char, (strlen(DEFAULT_CACHE_FILENAME) + 
-                                       strlen(options.extrafiles) + 
-                                       strlen(_DIR) + 1));
-
-          sprintf(default_file,"%s%s%s",
-                  options.extrafiles,
-                  _DIR,
-                  DEFAULT_CACHE_FILENAME);
-
-          if(!file_exists(default_file))
-          {
-               gtkeyboard_error(6, "Error:  Cannot find ", default_file,
-                                "\nPlease make sure that file exists before ",
-                                "using the word completion facility.\n",
-                                "Aborting word cache - cannot find suitable ",
-                                "default cache file.\n");
-               return(CACHE_FILENAME_ERROR);
+          if(file_exists(default_file)) {
+               gtkeyboard_message(3,"Found valid word list: ", default_file,
+                                  "\n");
+               ptr = g_strdup_(default_file);
+               return(ptr);
           } /* End if */
-     } /* End if */
-
-     /* This could be NULL - if so, that's OK */
-     return(default_file);
+     } /* End for */
+     
+     return(NULL);
 } /* End get_valid_cache_filename() */
 
 /* From is the filename to convert, to is the filename to save the new cache
@@ -306,7 +301,7 @@ int cacheify_file(char *from, char *to, int all_lowercase)
      {
           gtkeyboard_error(1, "Cannot make cache from non-existant file.\n");
           return(0);
-     }
+     } 
      else if(!file_exists(from) || !is_regular_file(from))
      {
           gtkeyboard_error(5, "Cannot make cache from file ", from, ": ",
@@ -331,8 +326,6 @@ int cacheify_file(char *from, char *to, int all_lowercase)
      if(cachefilename && strcmp(cachefilename, CACHE_FILENAME_ERROR) == 0)
           return(0);
      
-     fprintf(Q,"Cachefying-open.\n");
-     fflush(Q);
      comp = wcomp_open(cachefilename);
      
      if(cachefilename)
@@ -680,6 +673,7 @@ static void load_cache_file(GtkWidget *emitter, GtkFileSelection *fs)
           if(is_regular_file(filename))
           {
                fp = fopen(filename, "r");
+               
                if(!fp)
                {
                     gtkeyboard_error(4, "Error:  Cannot open ",filename,
@@ -818,11 +812,10 @@ void completer_window_new(void)
                              completion_slot[x], FALSE, FALSE, 0);
      } /* End for */
 
-     for(x=0; x<MAX_WORD_LENGTH; x++)
-          accumulator[x] = '\0';
+     /* Nuke the contents of the accumulator */
+     memset(accumulator, '\0', MAX_WORD_LENGTH);
 
      inputlabel = gtk_label_new("Current Text:  None");
-
      close = gtk_button_new_with_label("Close");
 
      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(completer_window)->vbox),
@@ -883,6 +876,7 @@ void completer_window_new(void)
      if(default_file && strcmp(default_file, CACHE_FILENAME_ERROR) == 0)
      {
           gtk_widget_destroy(completer_window);
+          gtkeyboard_error(1,"There was an error finding a cache filename");
           return;
      } /* End if */
      
@@ -890,7 +884,6 @@ void completer_window_new(void)
              default_file ? default_file : "NULL");
      fflush(Q);
      completer = wcomp_open(default_file);
-     
      /* Whoops...the completer wasn't able to be created for one reason or
       * another
       */
@@ -909,7 +902,7 @@ void completer_window_new(void)
      {
           g_free_(default_file);
      } /* End if */
-
+     
      wcomp_set_topnsize(completer, 10);
 
      /* ~/.gtkeyboard-wordcache */
@@ -918,7 +911,7 @@ void completer_window_new(void)
      else
           sprintf(cache_filename, "%s%s%s",
                   options.home, _DIR, COMPLETER_CACHE_FILENAME);
-
+     
      /* Try to read a cache file */
      if(options.cache_file)
           cache = fopen(options.cache_file, "r");
