@@ -791,7 +791,10 @@ static GtkWidget *create_options_menu(void)
      GtkWidget *move=NULL, *looks=NULL, *output=NULL, *redirection=NULL,
           *layout=NULL, *redirect=NULL, *ignore=NULL, *define=NULL,
           *toggleww=NULL, *togglesoe=NULL, *togglesl=NULL, *reset=NULL, 
-          *disable=NULL, *enable=NULL, *remote=NULL;
+          *remote=NULL, *stt=NULL;
+#if 0
+     GtkWidget *disable=NULL, *enable=NULL;
+#endif /* 0 */
 
      move        = gtk_menu_item_new_with_label("Move To...");
      looks       = gtk_menu_item_new_with_label("Looks");
@@ -826,10 +829,18 @@ static GtkWidget *create_options_menu(void)
      reset   = create_menu_item("Reset Looks", NULL, NULL,
                                 GTK_SIGNAL_FUNC(reset_application_style),
                                 NULL);
+
+     stt     = create_checked_item("Show Tooltips", 
+                                   GTK_SIGNAL_FUNC(toggle_tooltips), NULL,
+                                   options.SHOW_TOOLTIPS);
+     
+#if 0
      disable = create_menu_item("Disable ToolTips", NULL, NULL,
                                 GTK_SIGNAL_FUNC(disable_tooltips), NULL);
      enable  = create_menu_item("Enable ToolTips", NULL, NULL,
                                 GTK_SIGNAL_FUNC(enable_tooltips), NULL);
+#endif /* 0 */
+
      remote  = create_menu_item("Remote Control", "^R", NULL,
                                 GTK_SIGNAL_FUNC(gtkeyboard_remote_control),
                                 NULL);
@@ -844,14 +855,17 @@ static GtkWidget *create_options_menu(void)
      gtk_menu_append(GTK_MENU(menu), toggleww);
      gtk_menu_append(GTK_MENU(menu), togglesoe);
      gtk_menu_append(GTK_MENU(menu), togglesl);
+     gtk_menu_append(GTK_MENU(menu), stt);
      gtk_menu_append(GTK_MENU(menu), menu_hseparator_new());
      gtk_menu_append(GTK_MENU(menu), layout);
      gtk_menu_append(GTK_MENU(menu), redirect);
      gtk_menu_append(GTK_MENU(menu), ignore);
      gtk_menu_append(GTK_MENU(menu), define);
      gtk_menu_append(GTK_MENU(menu), reset);
+#if 0
      gtk_menu_append(GTK_MENU(menu), disable);
      gtk_menu_append(GTK_MENU(menu), enable);
+#endif /* 0 */
      gtk_menu_append(GTK_MENU(menu), remote);     
      return(menu);
 } /* End create_options_menu() */
@@ -905,13 +919,13 @@ static GtkWidget *create_help_menu(void)
 
      about   = create_menu_item("About", NULL, NULL,
                                 GTK_SIGNAL_FUNC(program_info),
-                                (gpointer)INFO_ABOUT);
+                                GINT_TO_POINTER(INFO_ABOUT));
      license = create_menu_item("License", NULL, NULL,
                                 GTK_SIGNAL_FUNC(program_info),
-                                (gpointer)INFO_LICENSE);
+                                GINT_TO_POINTER(INFO_LICENSE));
      new     = create_menu_item("What's New", NULL, NULL,
                                 GTK_SIGNAL_FUNC(program_info),
-                                (gpointer)INFO_CHANGELOG);
+                                GINT_TO_POINTER(INFO_CHANGELOG));
      splash_item  = create_menu_item("Splash", NULL, NULL,
                                      GTK_SIGNAL_FUNC(splash), NULL);
 
