@@ -816,13 +816,15 @@ GtkWidget *build_bottom_row_buttons(void)
 			GTK_SIGNAL_FUNC(save_file_as), NULL);
      /* About button mapped to program_info and INFO_ABOUT */
      gtk_signal_connect(GTK_OBJECT(output_aboutbutton), "clicked", 
-			GTK_SIGNAL_FUNC(program_info), (gpointer)INFO_ABOUT);
+			GTK_SIGNAL_FUNC(program_info), 
+                        GINT_TO_POINTER(INFO_ABOUT));
      /* Open button mapped to OpenFile, no args */
      gtk_signal_connect(GTK_OBJECT(output_openbutton), "clicked",
 			GTK_SIGNAL_FUNC(OpenFile), NULL);
      /* License button mapped to LICENSE, no args */
      gtk_signal_connect(GTK_OBJECT(output_licensebutton), "clicked",
-			GTK_SIGNAL_FUNC(program_info), (gpointer)INFO_LICENSE);
+			GTK_SIGNAL_FUNC(program_info), 
+                        GINT_TO_POINTER(INFO_LICENSE));
      /* Clear button mapped to output_clearbutton, (pop up dialog) */
      gtk_signal_connect(GTK_OBJECT(output_clearbutton), "clicked",
 			GTK_SIGNAL_FUNC(clear_all_text), GUI.main_output_text);
